# EwTools-package
This is a toolbox with helpful classes to be used when developing Everyware-projects. The entire documentation can be found [here](https://wiki.infomaker.se/display/IEUM/Everyware+Tools)

## Code and Syntax
We use basic [Psr standard](http://www.php-fig.org/) and [docBlocks](https://www.phpdoc.org/) to improve code standard an readability.

* [Psr-4](http://www.php-fig.org/psr/psr-4/) - Is used for improved autoloading.
* [Psr-1](http://www.php-fig.org/psr/psr-1/) and [Psr-2](http://www.php-fig.org/psr/psr-2/) - Are used as guidelines for code style and syntax in our way of writing our code.

### Naming conventions:
* ClassName
* methodName
* property_name
* $variable_name (even static variables)
* function_name (meant for global functions)
* CONSTANT_NAME (ment for both global and class constants)

A class (without docBlocks) may look like this:
```
<?php namespace Vendor\Package;
 
use FooInterface;
use BarClass as Bar;
use OtherVendor\OtherPackage\BazClass;
 
class FooBar extends Bar implements FooInterface {
    
    const VERSION = '1.0';
    const DATE_APPROVED = '2012-06-01';
    
    private static $static_variable = 'static data';
    
    public $property_name = 'FooBar property';
    
    private $sample_variable = 'under_score';
    
    public function sampleFunction( $a, $b = null ) {
        if ( $a === $b ) {
            bar();
        } elseif ( $a > $b ) {
            $foo->bar( $arg1 );
        } else {
            BazClass::bar( $arg2, $arg3 );
        }
    }

    final public static function bar() {
        // method body
    }
}
```

### How to write DocBlocks
We use docBlocks in our code to add documentation of how to use our tools. This documentation will be used to generate the documentation pages mentioned under "Documentation" later on. 

The basic DocBlock we use are might look like this:
```
/**
 * This is a summary.
 * This is a description
 *
 * @param string $argument1 This is the description.
 *
 * @since 0.1
 * @return void
 */
```

> More information on how to write docBlocks can be found [here](https://www.phpdoc.org/docs/latest/guides/docblocks.html)

## The generated documentation
We use [phpDocumentor](https://www.phpdoc.org/) to generate documentation from the sourcecode.
phpDocumentor is a command-line application that supports several commands with which you can generate your documentation.
It is required as "development dependency" or `require-dev` in Composer and will, as such, be managed by Composer.

As mentioned above, phpDocumentor uses the sourcecode to generate the documentation and in this DocBlocks are used most by us.  
This is also the only documentation we use and therefor we will strive to create our dockBlocks as instructive and accurate as possible.
It's also important to keep the dockBlocks up to date with the functionality of the tools.

### Configuration
phpDocumentor is configured from `phpdoc.dist.xml` like this:
```
<?xml version="1.0" encoding="UTF-8" ?>
<phpdoc>
    <parser>
        <target>docs</target>
        <markers>
            <item>TODO</item>
        </markers>
    </parser>
    <transformer>
        <target>./docs</target>
    </transformer>
    <files>
        <directory>src</directory>
    </files>
</phpdoc>
```

> More information on how to manage this file can be found [here](https://www.phpdoc.org/docs/latest/references/configuration.html).

Once installed, run the following command from root to generate a new set of documentations: 
```
$ vendor/bin/phpdoc
```

This will use the *config-file* to generate the documentation and output it in `/docs/`.  
You can find the documentation by opening `/docs/index.html` in a browser.

> __Note:__ By creating a `phpdoc.xml` we can override the main config-file and generate documentation from local configuration (_this file is ignored in git_).

## Tests

Tests have not been implemented yet but when we do we will use `PhpSpec` and `Codeception` for testing.
 
 * [PhpSpec](http://www.phpspec.net/en/stable/) - for function tests.
 * [Codeception](http://codeception.com/) - for integration-testing.