<?php namespace EwTools\Models;

use EwTools\Interfaces\Support\Selectable;
use EwTools\Storage\CollectionModel;
use EwTools\Support\Str;

/**
 * Section
 *
 * @link    http://infomaker.se
 * @package EwTools\Models
 * @since   EwTools\Models\Section 0.1
 */
class Section extends CollectionModel implements Selectable {
    
    protected $option_name = 'everyware_registered_sections_by_slug';
    
    protected $fields = [
        'name'       => '',
        'slug'       => '',
        'class_name' => '',
        'includes'   => ''
    ];
    
    /**
     * Return data in the form of an array fit for a select-box
     * A preselected value may be sent in.
     *
     * @param mixed $selected
     *
     * @since 0.1
     * @return array
     */
    public static function toSelect( $selected = null ) {
        return static::collection()->all()->map( function($section) use ($selected) {
            return [
                'value' => $section[ 'slug' ],
                'text'  => $section[ 'name' ],
                'selected' => $section['slug'] === $selected
            ];
        });
    }
    
    protected function onSet( $fields = [] ) {
        if ( Str::notEmpty($fields['name'] )) {
            $fields['slug'] = Str::slug($fields['name']);
        }
        return $fields;
    }
}