<?php
/**
 * Support: for detecting devices
 */
namespace EwTools\Support;

use InvalidArgumentException;

/**
 * Device
 *
 * @link    http://infomaker.se
 * @package EwTools\Support
 * @since   EwTools\Support\Device 0.1
 */
class Device {
    
    /**
     * Contains the device currently being used
     *
     * @var string
     */
    protected static $currentDevice;
    
    /**
	 * Retrieve current device used
	 *
	 * @since 0.1
	 * @return string
	 */
	public static function currentDevice() {
	    
	    if ( static::$currentDevice === null) {
	        static::setDevice(isset( $_SERVER['EVERY_DEVICE'] ) ? $_SERVER['EVERY_DEVICE'] : 'desktop');
	    }
		return static::$currentDevice;
	}
	
	/**
	 * Determine if device is mobile phone
	 *
	 * @since 0.1
	 * @return bool
	 */
	public static function isMobile() {
		return static::currentDevice() === 'mobile';
	}
	
	/**
	 * Determine if device is desktop
	 *
	 * @since 0.1
	 * @return bool
	 */
	public static function isDesktop() {
		return static::currentDevice() === 'desktop';
	}
	
	/**
	 * Determine if device tablet
	 *
	 * @since 0.1
	 * @return bool
	 */
	public static function isTablet() {
		return static::currentDevice() === 'tablet';
	}
    
    /**
     * Set the current device
     *
     * @param string $device
     *
     * @since 0.1
     * @return void
     */
    public static function setDevice( $device ) {
        $valid_devices = ['desktop','tablet','mobile'];
        
        if (! in_array($device, $valid_devices) ) {
            throw new InvalidArgumentException('Invalid device given');
        }
        static::$currentDevice = $device;
	}
}