<?php
/**
 * LinkedImage widget.
 * Plugin Name: Linked Image
 * Description: Upload and display an image and link it to a page or custom url.
 * Author: Infomaker
 * Author Uri: http://www.infomaker.se
 * Version: 1.0
 */
namespace EwWidgets\Widgets;

use EwTools\Admin\Widget;
use EwTools\Handler\Imengine;
use EwTools\Handler\Pages;
use EwTools\Models\Page;
use EwTools\Support\Str;

/**
 * LinkedImage
 *
 * @link    http://infomaker.se
 * @package EwTools\Widgets
 * @since   EwTools\Widgets\LinkedImage 0.1
 */
class LinkedImage extends Widget {
    
    /**
     * Twig-template to use
     *
     * @var string
     */
    protected $template_path = '@tools/widgets/linked-image';
    
    /**
     * Widget fields
     * Contains fields to manage an image-source and a url to bind it to
     *
     * @var array
     */
    protected $fields = [
        'image' => '',
        'page'  => '',
        'link'  => ''
    ];
    
    /**
     * LinkedImage constructor.
     *
     * @since 0.1
     */
    public function __construct() {
        $this->setWidgetData( __FILE__ );
        parent::__construct( 'ewc_linked_image' );
    }
    
    /**
     * Fires when rendering the widget form
     *
     * @param array $view_data
     *
     * @since 0.1
     * @return void
     */
    protected function edit( $view_data ) {
        $this->view( 'form', array_replace_recursive( $view_data, [
            'pages' => Pages::getSelectData(),
        ] ) );
    }
    
    /**
     * Fires when rendering widget
     *
     * @param array $view_data
     *
     * @since 0.1
     * @return void
     */
    protected function show( $view_data ) {
        $this->view( 'widget', array_replace_recursive( $view_data, [
            'image' => Imengine::cover( 1320, 800 )->fromSrc( $view_data[ 'image' ] ),
            'link'  => Str::notEmpty( $view_data[ 'link' ] ) ? $view_data[ 'link' ] : Page::createFromId($view_data[ 'page' ])->permalink()
        ] ) );
    }
}

LinkedImage::register();