<?php
/**
 * PageContent widget.
 *
 * Plugin Name: Page Content
 * Description: Render "The Content" from a specific page or the current page.
 * Version: 1.0
 * Author: Infomaker Scandinavia AB
 * Author URI: http://infomaker.se
 */
namespace EwWidgets\Widgets;

use EwTools\Admin\Widget;
use EwTools\Handler\Pages;
use EwTools\Models\Page;
use EwTools\Support\Str;

/**
 * PageContent
 *
 * @link    http://infomaker.se
 * @package EwTools\Widgets
 * @since   EwTools\Widgets\PageContent 0.1
 */
class PageContent extends Widget {
    
    /**
     * Twig-template to use
     *
     * @var string
     */
    protected $template_path = '@tools/widgets/page-content';
    
    /**
     * This widget has no fields because it only uses the pages content
     *
     * @var array
     */
    protected $fields = [
        'page' => ''
    ];
    
    /**
     * PageContent constructor.
     *
     * @since 0.1
     */
    public function __construct() {
        $this->setWidgetData( __FILE__ );
        parent::__construct( 'ew-page-content' );
    }
    
    /**
     * Fires when rendering the widget form
     *
     * @param array $view_data
     *
     * @since 0.1
     * @return void
     */
    protected function edit( $view_data ) {
        $this->view( 'form', array_replace_recursive([
            'pages' => Pages::getSelectData()
        ], $view_data));
    }
    
    /**
     * Fires when rendering widget
     *
     * @param array $view_data
     *
     * @since 0.1
     * @return void
     */
    protected function show( $view_data ) {
        $page = Str::notEmpty($view_data['page']) ? Page::createFromId($view_data['page']) : Page::current();
        $this->view( 'widget', array_replace( [
            'page_content' => wpautop( $page->content() )
        ], $view_data ) );
    }
}

PageContent::register();